@@ -3,7 +3,7 @@ from __future__ import annotations
 import functools
 import json
 from json import JSONDecodeError
-from typing import Any, List, Type, Union
+from typing import Any, Callable, List, Type, Union
 from urllib.parse import urlencode
 
 import requests
@@ -21,6 +21,7 @@ from fastapi_keycloak.exceptions import (
     UpdatePasswordException,
     UpdateProfileException,
     UpdateUserLocaleException,
+    UserNotFound,
     VerifyEmailException,
 )
 from fastapi_keycloak.model import (
@@ -221,7 +222,7 @@ class FastAPIKeycloak:
         """
         return OAuth2PasswordBearer(tokenUrl=self.token_uri)
 
-    def get_current_user(self, required_roles: List[str] = None, extra_fields: List[str] = None) -> OIDCUser:
+    def get_current_user(self, required_roles: List[str] = None, extra_fields: List[str] = None) -> Callable[OAuth2PasswordBearer, OIDCUser]:
         """Returns the current user based on an access token in the HTTP-header. Optionally verifies roles are possessed
         by the user
 
@@ -230,7 +231,7 @@ class FastAPIKeycloak:
             extra_fields List[str]: The names of the additional fields you need that are encoded in JWT
 
         Returns:
-            OIDCUser: Decoded JWT content
+            Callable[OAuth2PasswordBearer, OIDCUser]: Dependency method which returns the decoded JWT content
 
         Raises:
             ExpiredSignatureError: If the token is expired (exp > datetime.now())
@@ -259,11 +260,6 @@ class FastAPIKeycloak:
             decoded_token = self._decode_token(token=token, audience="account")
             user = OIDCUser.parse_obj(decoded_token)
             if required_roles:
-                if not user.realm_access:  # in cases where there are no roles in realm accessing
-                    raise HTTPException(
-                        status_code=status.HTTP_403_FORBIDDEN,
-                        detail=f"Role(s) {', '.join(required_roles)} is required to perform this action",
-                    )
                 for role in required_roles:
                     if role not in user.roles:
                         raise HTTPException(
@@ -849,6 +845,11 @@ class FastAPIKeycloak:
             response = self._admin_request(
                 url=f"{self.users_uri}/{user_id}", method=HTTPMethod.GET
             )
+            if response.status_code == status.HTTP_404_NOT_FOUND:
+                raise UserNotFound(
+                    status_code = status.HTTP_404_NOT_FOUND,
+                    reason=f"User with user_id[{user_id}] was not found"
+                )
             return KeycloakUser(**response.json())
 
     @result_or_error(response_model=KeycloakUser)
