@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import List, Optional
 
-from pydantic import BaseModel, SecretStr
+from pydantic import BaseModel, SecretStr, Field
 
 from fastapi_keycloak.exceptions import KeycloakError
 
@@ -109,7 +109,7 @@ class OIDCUser(BaseModel):
     preferred_username: Optional[str]
     realm_access: Optional[dict]
     resource_access: Optional[dict]
-    extra_fields: Optional[dict]
+    extra_fields: dict = Field(default_factory=dict)
 
     @property
     def roles(self) -> List[str]:
@@ -118,6 +118,11 @@ class OIDCUser(BaseModel):
         Returns:
             List[str]: If the realm access dict contains roles
         """
+        if not self.realm_access:
+            raise KeycloakError(
+                status_code=404,
+                reason="The 'realm_access' section of the provided access token is missing",
+            )
         try:
             return self.realm_access["roles"]
         except KeyError as e:
