@@ -4,7 +4,6 @@ from fastapi_keycloak import FastAPIKeycloak
 
 
 class BaseTestClass:
-
     @pytest.fixture
     def idp(self):
         return FastAPIKeycloak(
@@ -13,5 +12,5 @@ class BaseTestClass:
             client_secret="GzgACcJzhzQ4j8kWhmhazt7WSdxDVUyE",
             admin_client_secret="BIcczGsZ6I8W5zf0rZg5qSexlloQLPKB",
             realm="Test",
-            callback_uri="http://localhost:8081/callback"
+            callback_uri="http://localhost:8081/callback",
         )
